==> rest-assured-1.5-sources.jar: com/jayway/restassured/internal/ResponseLogSpecificationImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ResponseLogSpecificationImpl
  extends com.jayway.restassured.internal.LogSpecificationImpl  implements
    com.jayway.restassured.specification.ResponseLogSpecification {
public ResponseLogSpecificationImpl
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.ResponseSpecification body() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification all() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification everything() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification headers() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification cookies() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification status() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifError() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifStatusCodeIsEqualTo(int statusCode) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifStatusCodeMatches(org.hamcrest.Matcher<java.lang.Integer> matcher) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
}

==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/ResponseLogSpecificationImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ResponseLogSpecificationImpl
  extends com.jayway.restassured.internal.LogSpecificationImpl  implements
    com.jayway.restassured.specification.ResponseLogSpecification,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.ResponseSpecification body() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification body(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification all() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification all(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification everything() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification everything(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification headers() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification cookies() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification status() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifError() { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifStatusCodeIsEqualTo(int statusCode) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
public  com.jayway.restassured.specification.ResponseSpecification ifStatusCodeMatches(org.hamcrest.Matcher<java.lang.Integer> matcher) { return (com.jayway.restassured.specification.ResponseSpecification)null;}
}
